1.1.2 (27-Sep-2018)
===================

**Features**
* Support listing instances
* Make merge_time use float seconds


1.1.1 (26-Sep-2018)
===================

**Features**
* Command history retrieval

